# -*- coding: UTF-8 -*-
import re
import json


def get_tags():
    return ['1', '1.3']


def run_task(runcontext):
    ansible_params = runcontext.get_mod_params_instance()
    runcontext.set_mod_params_instance(ansible_params, "chdir", None)
    runcontext.set_mod_params_instance(ansible_params, "executable", None)

    module = runcontext.get_module_file("shell.py")
    rc, out = run_audit(runcontext, ansible_params, module)
    return rc, out


def run_audit(runcontext, ansible_params, module):
    curtemplate = runcontext.get_template()
    tmp_vars = {}
    tmp_vars["policyresult"] = "failed"

    tmp_vars["checkresult1"] = "failed"
    tmp_vars["scancommand1"] = r"cat /etc/pam.d/common-password | grep -v '^[[:space:]]*#' | grep password | egrep 'requisite|required' | grep pam_pwquality.so | egrep 'minlen|dcredit|ucredit|ocredit|lcredit'"
    tmp_vars["systemvalue1"] = ""

    tmp_vars["checkresult2"] = "failed"
    tmp_vars["scancommand2"] = '''dpkg -s libpam-pwquality | egrep "install\s+ok\s+installed"'''
    tmp_vars["systemvalue2"] = ""


    runcontext.set_mod_params_instance(ansible_params, "command", tmp_vars["scancommand1"])
    arc1, astdout1, astderr1 = runcontext.invoke_module(module, ansible_params)
    runcontext.log_debug_invoke_result(arc1, astdout1, astderr1)
    runcontext.sleep()

    runcontext.set_mod_params_instance(ansible_params, "command", tmp_vars["scancommand2"])
    arc2, astdout2, astderr2 = runcontext.invoke_module(module, ansible_params)
    runcontext.log_debug_invoke_result(arc2, astdout2, astderr2)
    runcontext.sleep()




    if arc1 != 0:
        return (-2, "Failed to invoke module: %s." % astdout1)
    resultjson1 = json.loads(astdout1)
    astdout1 = resultjson1["stdout"]
    astderr1 = resultjson1["stderr"]
    match1_found = re.match(r".*minlen\s*=\s*(([1-9]\d+)|([8-9]))", astdout1) and re.match(r".*dcredit\s*=\s*-([1-9]\d+|[1-9])", astdout1) and re.match(r".*ucredit\s*=\s*-([1-9]\d+|[1-9])", astdout1) and re.match(r".*lcredit\s*=\s*-([1-9]\d+|[1-9])", astdout1) and re.match(r".*ocredit\s*=\s*-([1-9]\d+|[1-9])", astdout1)
    tmp_vars["systemvalue1"] = astdout1
    if match1_found:
        tmp_vars["checkresult1"] = "pass"

    if arc2 != 0:
        return (-2, "Failed to invoke module: %s." % astdout2)
    resultjson2 = json.loads(astdout2)
    astdout2 = resultjson2["stdout"]
    astderr2 = resultjson2["stderr"]
    match2 = re.match(r".*install ok installed.*", astdout2)
    tmp_vars["systemvalue2"] = astdout2
    if match2:
        tmp_vars["checkresult2"] = "pass"


    if tmp_vars["checkresult1"] == "pass" and tmp_vars["checkresult2"] == "pass":
        tmp_vars["policyresult"] = "pass"
        ret_code = 0
    else:
        ret_code = -1

    rc, out = curtemplate.render(runcontext.get_template_file('t_1_3.j2'), **tmp_vars)

    if rc == False:
        return (-2, "Failed to render template.%s" % out)

    return ret_code, out
